# Example Code from [Qualys API Best Practices Series](https://blog.qualys.com/tag/api-best-practices-series)

BETA Release of Example code from the [Qualys API Best Practices Series](https://blog.qualys.com/tag/api-best-practices-series) 
enhanced with some packaging and operational capability. 
> This example code is being actively developed at Qualys.  The etl_host_list and etl_knowledgebase 
> functions of qetl_manage_user are in BETA Test.  The etl_host_list_detection is in development.  
> See [Roadmap](#roadmap) for additonal details.

The component diagram depicts major system interoperability components that deliver data into the enterprise.  

See  [qualys_etl directory](/qualys_etl#readme) for details.

[![](https://user-images.githubusercontent.com/82658653/120926641-c1ea5800-c6ab-11eb-832b-1af03f77462a.png)](https://user-images.githubusercontent.com/82658653/120926641-c1ea5800-c6ab-11eb-832b-1af03f77462a.png)




